@@ -1,4 +1,4 @@
-from .backends import current as _be
+from .backends import current as _be, Deadlock as _Deadlock
 
 
 # noinspection PyPep8Naming,PyShadowingNames
@@ -38,7 +38,7 @@ class dcase(object):
         return False
 
 
-def select(cases):
+def select(*cases):
     """
     Select the first case that becomes ready.
     If a default case (:class:`goless.dcase`) is present,
@@ -54,6 +54,19 @@ def select(cases):
     :return: ``(chosen case, received value)``.
       If the chosen case is not an :class:`goless.rcase`, it will be None.
     """
+    if len(cases) == 0:
+        return
+    # If the first argument is a list, it should be the only argument
+    if isinstance(cases[0], list):
+        if len(cases) != 1:
+            raise TypeError('Select can be called either with a list of cases '
+                            'or multiple case arguments, but not both.')
+        cases = cases[0]
+        if not cases:
+            # Handle the case of an empty list as an argument,
+            # and prevent the raising of a SystemError by libev.
+            return
+
     default = None
     for c in cases:
         if c.ready():
@@ -65,6 +78,14 @@ def select(cases):
         # noinspection PyCallingNonCallable
         return default, None
 
+    # We need to check for deadlocks before selecting.
+    # We can't rely on the underlying backend to do it,
+    # as we do for channels, since we don't do an actual send or recv here.
+    # It's possible to still have a deadlock unless we move the check into
+    # the loop, but since the check is slow
+    # (gevent doesn't provide a fast way), let's leave it out here.
+    if _be.would_deadlock():
+        raise _Deadlock('No other tasklets running, cannot select.')
     while True:
         for c in cases:
             if c.ready():
